pub(crate) struct WrappedLocalUserDataKey(pub(crate) EncString);Expand description
An indirect symmetric key for encrypting local user data (e.g. password generator history). Enables offline decryption of local data after a key rotation: only the wrapped key is re-encrypted; the local user data key itself stays intact.
Tuple Fields
0: EncStringImplementations
Sourceimpl WrappedLocalUserDataKey
impl WrappedLocalUserDataKey
Sourcepub(crate) fn from_context_user_key(
ctx: &mut KeyStoreContext<'_, KeyIds>,
) -> Result<Self, LocalUserDataKeyError>
pub(crate) fn from_context_user_key( ctx: &mut KeyStoreContext<'_, KeyIds>, ) -> Result<Self, LocalUserDataKeyError>
Create a user key, wrapped by the user key.
Sourcepub(crate) fn unwrap_to_context(
&self,
ctx: &mut KeyStoreContext<'_, KeyIds>,
) -> Result<(), LocalUserDataKeyError>
pub(crate) fn unwrap_to_context( &self, ctx: &mut KeyStoreContext<'_, KeyIds>, ) -> Result<(), LocalUserDataKeyError>
Unwrap the local user data key and set it in the context under the
SymmetricKeyId::LocalUserData key id.